args property
ControlArgs
get
args
A shortcut to access the arguments and dependencies stored in the CoreContext.
Implementation
ControlArgs get args => element.args;
A shortcut to access the arguments and dependencies stored in the CoreContext.
ControlArgs get args => element.args;