isDirty property
bool
get
isDirty
Checks if the element is marked as dirty and needs to be rebuilt.
Implementation
bool get isDirty => element.dirty;
Checks if the element is marked as dirty and needs to be rebuilt.
bool get isDirty => element.dirty;