initArgs property
A map of initial arguments to be passed to the CoreContext.
These arguments can be retrieved within the widget's lifecycle using
context.get<T>() or context.args.
Implementation
final Map initArgs;
A map of initial arguments to be passed to the CoreContext.
These arguments can be retrieved within the widget's lifecycle using
context.get<T>() or context.args.
final Map initArgs;