softDispose method

void softDispose()

A method for partial disposal, like canceling subscriptions, without fully invalidating the object.

This is useful for objects that are temporarily inactive but may be reused, such as items in a recycled list view.

Implementation

void softDispose() {}