RouteNavigator class abstract

Providing basic type of navigation.

Implementers

Constructors

RouteNavigator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

backTo<T>({Route? route, String? identifier, bool predicate(Route)?, Route? open}) → void
Navigates back in the stack until a route matching the predicate is found.
backToRoot({Route? open}) → void
Navigates back to the very first route in the navigation stack.
close([dynamic result]) bool
Pops the current route from the navigation stack. A result can be passed back to the previous route.
closeRoute(Route route, [dynamic result]) bool
Removes a specific route from the navigator.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openRoot(Route route) Future
Pushes a Route and removes all previous routes from the stack.
openRoute(Route route, {bool root = false, bool replacement = false}) Future
Pushes a Route onto the navigation stack.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited