onChangeState method
Called when the state is notified of a change from one of its notifiers.
Implementation
@protected
void onChangeState(ControlState state, dynamic value) {}
Called when the state is notified of a change from one of its notifiers.
@protected
void onChangeState(ControlState state, dynamic value) {}