BroadcastSubscriptionArgs<T> class

Arguments for creating a BroadcastSubscription.

This class encapsulates the parameters needed to create a subscription, making it easier to pass them around.

Constructors

BroadcastSubscriptionArgs({required dynamic key, bool nullOk = true})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key → dynamic
The unique key to identify the broadcast stream.
final
nullOk bool
Whether null values are considered valid for this subscription. If false, null values broadcasted on this channel will be ignored.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createSubscription() BroadcastSubscription<T>
Creates a new BroadcastSubscription instance from these arguments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited