ControlState<U extends _ControlWidgetBase> class
The State object for a _ControlWidgetBase.
It manages the lifecycle of the ControlModels provided by the widget.
Constructors
Properties
- args → ControlArgs
-
A shortcut to access the arguments and dependencies stored in the CoreContext.
no setterinherited
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
-
controls
↔ List<
ControlModel> -
The list of ControlModels managed by this state.
getter/setter pair
- element → CoreContext
-
A typed getter for the widget's context, which is always a CoreContext.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDirty → bool
-
Checks if the element is marked as dirty and needs to be rebuilt.
no setterinherited
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widget → U
-
The current configuration.
no setterinherited
Methods
-
activate(
) → void -
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
deactivate(
) → void -
Called when this object is removed from the tree.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(
covariant U oldWidget) → void -
Called whenever the widget configuration changes.
inherited
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
override
-
initState(
) → void -
Called when this object is inserted into the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyState(
[dynamic state]) → void -
Schedules a rebuild of the widget.
state- An optional state value passed toonChangeState.override -
onInit(
) → void -
A callback from CoreContext, indicating that the state has been fully
initialized and all dependencies are ready.
override
-
reassemble(
) → void -
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
setState(
VoidCallback fn) → void -
Notify the framework that the internal state of this object has changed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited