Initializable class abstract
An interface for objects that can be initialized with arguments after construction.
This allows for a form of dependency injection or late initialization where dependencies are provided via the init method instead of the constructor.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
init(
Map args) → void - Initializes the object with a map of arguments.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited