ObservableValue<T> class
abstract
An observable that holds and notifies about changes to a single value.
This is the most common type of observable, used for representing reactive state.
- Implemented types
- Available extensions
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- internalData ↔ dynamic
-
Optional data that can be attached to the observable, often for internal
use by components or for tracking purposes.
getter/setter pairoverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T
-
The current value held by the observable.
no setter
Methods
-
cancel(
ControlSubscription< T> subscription) → void -
Cancels a subscription, preventing it from receiving further notifications.
inherited
-
cast<
U> () → ObservableValue< U> -
Available on ObservableValue, provided by the ObservableValuExt extension
Cast this observable. -
dispose(
) → void -
Releases resources used by the object.
inherited
-
disposeWith(
DisposeObserver observer) → void -
Available on Disposable, provided by the DisposableExt extension
Register for dispose with givenobserver. -
listen(
VoidCallback action) → ControlSubscription< T> -
Subscribes to the observable to be notified of changes.
override
-
merge(
Object other) → ObservableGroup -
Available on ObservableBase, provided by the ObservableBaseExt extension
Creates new group, that listens to both observables. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
subscribe(
ValueCallback< T> action, {bool current = false, dynamic args}) → ControlSubscription<T> - Subscribes to changes in the observable's value.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited