OnLayout mixin
A mixin for a CoreWidget that provides a callback after the first frame is rendered.
This is useful for performing actions that require the widget to be laid out and have a size, such as showing an overlay or starting an animation.
- Superclass constraints
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- initArgs → Map
-
A map of initial arguments to be passed to the CoreContext.
finalinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → CoreContext -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → CoreState< CoreWidget> -
Creates the mutable state for this widget at a given location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
init(
CoreContext context) → void -
A preliminary initialization method called by the CoreContext.
This is a good place for mixins to hook into the initialization process.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDependencyChanged(
CoreContext context) → void -
Called when a dependency of this widget changes.
See State.didChangeDependencies for more information.
inherited
-
onDispose(
) → void -
Called when the widget is being disposed.
inherited
-
onInit(
Map args, CoreContext context) → void -
Called once when the state is fully initialized and the context is available.
override
-
onLayout(
CoreContext context) → void - Called once after the first frame of the widget has been rendered.
-
onUpdate(
CoreContext context, CoreWidget oldWidget) → void -
Called when the widget is updated with new configuration.
See State.didUpdateWidget for more information.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited