ParseN class
A utility class with static methods for parsing data types that can explicitly return null.
This is in contrast to the main Parse class, where methods typically return a non-nullable default value on failure.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
string(
dynamic value) → String? -
Tries to parse a value into a String. Returns
nullon failure. -
toBool(
dynamic value) → bool? -
Tries to parse a value into a bool. Returns
nullon failure. Handlesint,double,bool, andStringinputs. -
toDouble(
dynamic value) → double? -
Tries to parse a value into a double. Returns
nullon failure. Handlesint,double,bool, andStringinputs. -
toInteger(
dynamic value) → int? -
Tries to parse a value into an int. Returns
nullon failure. Handlesint,double,bool, andStringinputs.